# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.alert_rules_v1_api import AlertRulesV1Api


class TestAlertRulesV1Api(unittest.TestCase):
    """AlertRulesV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = AlertRulesV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_alert_rule(self) -> None:
        """Test case for delete_alert_rule

        Delete Alert Rule By Id
        """
        pass

    def test_get_alert_rule(self) -> None:
        """Test case for get_alert_rule

        Get Alert Rule By Id
        """
        pass

    def test_get_model_alert_rules(self) -> None:
        """Test case for get_model_alert_rules

        Get Model Alert Rules
        """
        pass

    def test_patch_alert_rule(self) -> None:
        """Test case for patch_alert_rule

        Update Model Alert Rule
        """
        pass

    def test_post_alert_rule_query_validation(self) -> None:
        """Test case for post_alert_rule_query_validation

        Validate A Model Alert Rule Query
        """
        pass

    def test_post_model_alert_rule(self) -> None:
        """Test case for post_model_alert_rule

        Create Model Alert Rule
        """
        pass


if __name__ == '__main__':
    unittest.main()
