# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.projects_v1_api import ProjectsV1Api


class TestProjectsV1Api(unittest.TestCase):
    """ProjectsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_project(self) -> None:
        """Test case for delete_project

        Delete Project.
        """
        pass

    def test_get_project(self) -> None:
        """Test case for get_project

        Get Project
        """
        pass

    def test_get_projects(self) -> None:
        """Test case for get_projects

        Get Projects.
        """
        pass

    def test_patch_project(self) -> None:
        """Test case for patch_project

        Patch Project.
        """
        pass

    def test_post_project(self) -> None:
        """Test case for post_project

        Post Project.
        """
        pass


if __name__ == '__main__':
    unittest.main()
